ete2.treeview.faces.TextFace

Package ete2 :: Package treeview :: Module faces :: Class TextFace |
[hide private]
[frames] | no frames]

# Class TextFace

source code

    object --+
             |
          Face --+
                 |
                TextFace

Known Subclasses:
  - AttrFace

    Creates a new text face object.

    Arguments description
    ---------------------
    text:     Text to be drawn
    ftype:    Font type, e.g. Arial, Verdana, Courier, (default="Verdana")
    fsize:    Font size, e.g. 10,12,6, (default=10)
    fgcolor:  Foreground font color in RGB name format, e.g. #FF00DD,#000000  (default="#000000")
    bgcolor:  Backgroung font color in RGB name format, e.g. #FFFFFF,#DDDDDD, (default=None)
    penwidth: Penwdith used to draw the text. (default is 0)

Instance Methods | [hide private]
__init__(self, text, ftype=`'``Verdana``'`, fsize=10, fgcolor=`'``#000000``'`, bgcolor=None, penwidth=0) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
_height(self) | source code
_width(self) | source code
get_text(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`
Inherited from Face
_size(self) | source code
load_pixmap_from_file(self, filename) | source code
update_pixmap(self) | source code

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, text, ftype=`'``Verdana``'`, fsize=10, fgcolor=`'``#000000``'`, bgcolor=None, penwidth=0) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### _height(self) | source code
Overrides: Face._height

### _width(self) | source code
Overrides: Face._width